summaryrefslogtreecommitdiffstats
path: root/konqueror/konq_mainwindow.cc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-03-31 23:10:03 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2014-03-31 23:10:03 -0500
commit24e34ad9892c4c5bf774bd0c32e369be52954936 (patch)
tree03819b1b63f5b60797d8072e1bda8a35fcefaf52 /konqueror/konq_mainwindow.cc
parent39cbbdb1607e656aac07834d77573b204a717540 (diff)
downloadtdebase-24e34ad9892c4c5bf774bd0c32e369be52954936.tar.gz
tdebase-24e34ad9892c4c5bf774bd0c32e369be52954936.zip
Add basic support for a modified compton compositor instead of the old buggy kompmgr
Update additional Xorg atom names
Diffstat (limited to 'konqueror/konq_mainwindow.cc')
-rw-r--r--konqueror/konq_mainwindow.cc4
1 files changed, 2 insertions, 2 deletions
diff --git a/konqueror/konq_mainwindow.cc b/konqueror/konq_mainwindow.cc
index ecd78b7cf..f7ebf9d6c 100644
--- a/konqueror/konq_mainwindow.cc
+++ b/konqueror/konq_mainwindow.cc
@@ -5807,10 +5807,10 @@ void KonqMainWindow::resetWindow()
XEvent ev;
XWindowEvent( tqt_xdisplay(), tmp_widget.winId(), PropertyChangeMask, &ev );
long x_time = ev.xproperty.time;
// bad hack - without updating the _KDE_NET_WM_USER_CREATION_TIME property,
// KWin will apply don't_steal_focus to this window, and will not make it active
// (shows mainly with 'konqueror --preload')
- static Atom atom = XInternAtom( tqt_xdisplay(), "_KDE_NET_WM_USER_CREATION_TIME", False );
+ static Atom atom = XInternAtom( tqt_xdisplay(), "_TDE_NET_WM_USER_CREATION_TIME", False );
XChangeProperty( tqt_xdisplay(), winId(), atom, XA_CARDINAL, 32,
PropModeReplace, (unsigned char *) &x_time, 1);
SET_QT_X_USER_TIME(CurrentTime); // won't have _NET_WM_USER_TIME set
@@ -5807,10 +5807,10 @@ void KonqMainWindow::resetWindow()
XWindowEvent( tqt_xdisplay(), tmp_widget.winId(), PropertyChangeMask, &ev );
long x_time = ev.xproperty.time;
- // bad hack - without updating the _KDE_NET_WM_USER_CREATION_TIME property,
+ // bad hack - without updating the _TDE_NET_WM_USER_CREATION_TIME property,
// KWin will apply don't_steal_focus to this window, and will not make it active
// (shows mainly with 'konqueror --preload')